Library that simplifies creating user interfaces with wxPython.

* License: GPLv3
* Contributions: Fork this repository and send a pull request

For more information, see the `documentation
<http://humblewx.readthedocs.org/en/latest/>`_.
